@@ -8,7 +8,7 @@ use File::Basename qw/basename dirname/;
 use File::Spec ();
 
 use vars qw/$VERSION/;
-$VERSION = '1.0';
+$VERSION = '1.1';
 use vars qw/@ISA/;
 @ISA = qw/DynaLoader/;
 
@@ -72,10 +72,7 @@ sub open_hdlist {
 sub open_package {
   my $class = shift;
   my $file = shift;
-  my $flags = shift;
-
-  $flags = RPM2->vsf_default;
-  $flags ||= 0;
+  my $flags = shift // RPM2->vsf_default // 0;
 
   open FH, "<$file"
     or die "Can't open $file: $!";
@@ -91,13 +88,9 @@ sub open_package {
 sub create_transaction
 {
   my $class = shift;
-  my $flags = shift;
+  my $flags = shift // RPM2->vsf_default // 0;
   my $t;
 
-  if(not defined $flags) {
-    $flags = RPM2->vsf_default;
-  }
-
   $t = RPM2::_create_transaction($flags);
   $t = RPM2::Transaction->_new_raw($t);
 
@@ -106,6 +99,8 @@ sub create_transaction
 
 package RPM2::DB;
 
+$VERSION = $RPM2::VERSION;
+
 sub find_all_iter {
   my $self = shift;
 
@@ -174,6 +169,8 @@ sub find_by_file {
 
 package RPM2::Header;
 
+$VERSION = $RPM2::VERSION;
+
 use overload '<=>'  => \&op_spaceship,
              'cmp'  => \&op_spaceship,
              'bool' => \&op_bool;
@@ -334,6 +331,8 @@ sub changelog {
 
 package RPM2::PackageIterator;
 
+$VERSION = $RPM2::VERSION;
+
 sub new_iterator {
   my $class = shift;
   my $db = shift;
@@ -380,6 +379,8 @@ sub DESTROY {
 
 package RPM2::Transaction;
 
+$VERSION = $RPM2::VERSION;
+
 sub _new_raw {
   my $class         = shift;
   my $c_transaction = shift;
@@ -802,7 +803,7 @@ and contributions were made by numerous authors. It is currently maintained
 by Lubomir Rintel E<lt>lkundrak@v3.skE<gt>.
 
 The source code is kept in a L<Git> repository at
-L<git://git.fedorahosted.org/perl-RPM2.git>.
+L<https://github.com/lkundrak/perl-RPM2.git>.
 
 =head1 BUGS
 
